/*
Nome: 9814_CDPTRGS_LOG_CDP_FOTOESPEPROD.SQL

Descrio:
   Trigger para gravar o log das alteraes

Criao:
   17/02/2009 - Henrique Guidi Lobato
Descrio: A trigger insere registros na tabela LOGOPERA a partir das alteraes na tabela
              FOTOESPEPROD, para verifio de erros
*/
IF EXISTS(SELECT *
          FROM SYSOBJECTS O, SYSUSERS U
          WHERE O.NAME = 'LOG_CDP_FOTOESPEPROD' AND
                TYPE   = 'TR'                   AND
                U.UID  = O.UID                  AND
                U.NAME = USER)

DROP TRIGGER LOG_CDP_FOTOESPEPROD
GO


CREATE TRIGGER LOG_CDP_FOTOESPEPROD
ON FOTOESPEPROD
FOR UPDATE,INSERT, DELETE
AS
BEGIN

   DECLARE @V_DSREMOTEADDR VARCHAR(15);
   DECLARE @V_DSREMOTEHOST VARCHAR(15);
   DECLARE @V_DSSERVERRDM  VARCHAR(20);
   DECLARE @V_DSSERVMETHOD VARCHAR(30);
   DECLARE @V_DSREMOTEOPER VARCHAR(12);
   DECLARE @V_DESC         VARCHAR(500);
   DECLARE @V_ITPESQ       VARCHAR(80);
   DECLARE @V_NMOPERADOR   VARCHAR(40);
   DECLARE @V_IDCLIEATIV   VARCHAR(1);
   DECLARE @V_NRINCREST    VARCHAR(40);
   DECLARE @V_IDTIPOOPER   VARCHAR(1);

/*VARIVEIS DO CURSOR C_CURSOR*/
   DECLARE @V_ID_TRIGGER       VARCHAR(1);

   DECLARE @V_CDPRODUTO_OLD    VARCHAR(10);
   DECLARE @V_CDESPEPROD_OLD   VARCHAR(10);
   DECLARE @V_NRFGESPEPROD_OLD VARCHAR(2);
   DECLARE @V_IDFGESPEATIV_OLD CHAR(1);
   DECLARE @V_IDAJUSFGESPE_OLD CHAR(1);

   DECLARE @V_CDPRODUTO_NEW    VARCHAR(10);
   DECLARE @V_CDESPEPROD_NEW   VARCHAR(10);
   DECLARE @V_NRFGESPEPROD_NEW VARCHAR(2);
   DECLARE @V_IDFGESPEATIV_NEW CHAR(1);
   DECLARE @V_IDAJUSFGESPE_NEW CHAR(1);

/* IDTIPOOPER - '1' - Incluso, '2' - Alterao, '3' - Excluso*/

   SET @V_DESC       = '';
   SET @V_ITPESQ     = '';
   SET @V_NMOPERADOR = '';
   SET @V_IDCLIEATIV = '';
   SET @V_NRINCREST  = '';
   SET @V_IDTIPOOPER = '';

   EXEC NMUSUARIO  @V_NMOPERADOR;
   EXEC WEBTUNNING @V_DSREMOTEADDR,
                   @V_DSREMOTEHOST,
                   @V_DSSERVERRDM,
                   @V_DSSERVMETHOD,
                   @V_DSREMOTEOPER;

   DECLARE C_CURSOR CURSOR FOR
      SELECT
         'D' IDCOMANDO,
         CDPRODUTO,
         CDESPEPROD,
         NRFGESPEPROD,
         IDFGESPEATIV,
         IDAJUSFGESPE,
         NULL,
         NULL,
         NULL,
         NULL,
         NULL

      FROM
         DELETED
      WHERE
         0 = (SELECT COUNT(*) FROM INSERTED)
      UNION ALL

      SELECT
         'U' IDCOMANDO,
         DELETED.CDPRODUTO,
         DELETED.CDESPEPROD,
         DELETED.NRFGESPEPROD,
         DELETED.IDFGESPEATIV,
         DELETED.IDAJUSFGESPE,
         INSERTED.CDPRODUTO,
         INSERTED.CDESPEPROD,
         INSERTED.NRFGESPEPROD,
         INSERTED.IDFGESPEATIV,
         INSERTED.IDAJUSFGESPE

      FROM
         INSERTED,
         DELETED
      WHERE
         INSERTED.CDPRODUTO  = DELETED.CDPRODUTO

      UNION ALL

      SELECT
        'I' IDCOMANDO,
         NULL,
         NULL,
         NULL,
         NULL,
         NULL,
         CDPRODUTO,
         CDESPEPROD,
         NRFGESPEPROD,
         IDFGESPEATIV,
         IDAJUSFGESPE

     FROM
        INSERTED
     WHERE
        0 = (SELECT COUNT(*) FROM DELETED)

   OPEN C_CURSOR;
   FETCH NEXT FROM C_CURSOR INTO @V_ID_TRIGGER,
                                
                                 @V_CDPRODUTO_OLD,    
                                 @V_CDESPEPROD_OLD,   
                                 @V_NRFGESPEPROD_OLD, 
                                 @V_IDFGESPEATIV_OLD, 
                                 @V_IDAJUSFGESPE_OLD,

                                 @V_CDPRODUTO_NEW,    
                                 @V_CDESPEPROD_NEW,   
                                 @V_NRFGESPEPROD_NEW, 
                                 @V_IDFGESPEATIV_NEW, 
                                 @V_IDAJUSFGESPE_NEW;



   WHILE (@@FETCH_STATUS = 0) BEGIN

    IF @V_ID_TRIGGER = 'I' BEGIN

           IF @V_CDPRODUTO_NEW IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'CdProd= ' + ISNULL(@V_CDPRODUTO_NEW,'') + ' ';
           END;

           IF @V_CDESPEPROD_NEW IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'CdEspecificProd= ' + ISNULL(@V_CDESPEPROD_NEW,'') + ' ';
           END;

           IF @V_NRFGESPEPROD_NEW IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'NrSequencialFotoEspProd= ' + ISNULL(@V_NRFGESPEPROD_NEW,'')  + ' ';
           END;

           IF @V_IDFGESPEATIV_NEW IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'IdFotoAtivaEspProd= ' + ISNULL(@V_IDFGESPEATIV_NEW,'') + ' ';
           END;

           IF @V_IDAJUSFGESPE_NEW IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'IdAjusteFotoTela= ' + ISNULL(@V_IDAJUSFGESPE_NEW,'') + ' ';
           END;

        SET @V_ITPESQ = @V_CDPRODUTO_NEW    + @V_CDESPEPROD_NEW + @V_NRFGESPEPROD_NEW + @V_IDFGESPEATIV_NEW +
                         @V_IDAJUSFGESPE_NEW;

        SET @V_IDTIPOOPER = '1';
     END
     ELSE BEGIN
        IF @V_ID_TRIGGER = 'U' BEGIN

           IF (@V_CDPRODUTO_OLD <> @V_CDPRODUTO_NEW) BEGIN
              SET @V_DESC = @V_DESC + 'CdProd= ' + ISNULL(@V_CDPRODUTO_NEW,'') + ' ';
           END;

           IF (@V_CDESPEPROD_OLD <> @V_CDESPEPROD_NEW) BEGIN
              SET @V_DESC = @V_DESC + 'CdEspecificProd= ' + ISNULL(@V_CDESPEPROD_NEW,'') + ' ';
           END;

           IF (@V_NRFGESPEPROD_OLD <> @V_NRFGESPEPROD_NEW) BEGIN
              SET @V_DESC = @V_DESC + 'NrSequencialFotoEspProd= ' + ISNULL(@V_NRFGESPEPROD_NEW,'')  + ' ';
           END;

           IF (@V_IDFGESPEATIV_OLD <> @V_IDFGESPEATIV_NEW) BEGIN
              SET @V_DESC = @V_DESC + 'IdFotoAtivaEspProd= ' + ISNULL(@V_IDFGESPEATIV_NEW,'') + ' ';
           END;

           IF (@V_IDAJUSFGESPE_OLD <> @V_IDAJUSFGESPE_NEW) BEGIN
              SET @V_DESC = @V_DESC + 'IdAjusteFotoTela= ' + ISNULL(@V_IDAJUSFGESPE_NEW,'') + ' ';
           END;

           SET @V_ITPESQ = @V_CDPRODUTO_NEW    + @V_CDESPEPROD_NEW + @V_NRFGESPEPROD_NEW + @V_IDFGESPEATIV_NEW +
                           @V_IDAJUSFGESPE_NEW;

           SET @V_IDTIPOOPER = '2';

        END;

        IF @V_ID_TRIGGER = 'D'  BEGIN

           IF @V_CDPRODUTO_OLD IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'CdProd= ' + ISNULL(@V_CDPRODUTO_OLD,'') + ' ';
           END;

           IF @V_CDESPEPROD_OLD IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'CdEspecificProd= ' + ISNULL(@V_CDESPEPROD_OLD,'') + ' ';
           END;

           IF @V_NRFGESPEPROD_OLD IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'NrSequencialFotoEspProd= ' + ISNULL(@V_NRFGESPEPROD_OLD,'')  + ' ';
           END;

           IF @V_IDFGESPEATIV_OLD IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'IdFotoAtivaEspProd= ' + ISNULL(@V_IDFGESPEATIV_OLD,'') + ' ';
           END;

           IF @V_IDAJUSFGESPE_OLD IS NOT NULL BEGIN
              SET @V_DESC = @V_DESC + 'IdAjusteFotoTela= ' + ISNULL(@V_IDAJUSFGESPE_OLD,'') + ' ';
           END;

           SET @V_ITPESQ = @V_CDPRODUTO_OLD    + @V_CDESPEPROD_OLD + @V_NRFGESPEPROD_OLD + @V_IDFGESPEATIV_OLD +
                           @V_IDAJUSFGESPE_OLD;

           SET @V_IDTIPOOPER = '3';
        END;
     END;

     IF NOT (@V_DESC IS NULL) BEGIN

        INSERT INTO LOGOPERA ( NMTABELA, DTOPERACAO, NMRESPOPER,
                               IDTIPOOPER,   DSOPERACAO, CDPESQITEM,
                               DSRDMUSUOPER, DSENDUSUOPER, DSNMUSUOPER,
                               DSMETUSUOPER, CDORESPOPER)
                    VALUES   ('FOTOESPEPROD', GETDATE() ,    ISNULL(@V_NMOPERADOR,' '),
                               @V_IDTIPOOPER,   @V_DESC, @V_ITPESQ,
                               @V_DSSERVERRDM, @V_DSREMOTEADDR,  @V_DSREMOTEHOST,
                               @V_DSSERVMETHOD,   @V_DSREMOTEOPER);
     END;

   FETCH NEXT FROM C_CURSOR INTO @V_ID_TRIGGER,

                                 @V_CDPRODUTO_OLD,    
                                 @V_CDESPEPROD_OLD,   
                                 @V_NRFGESPEPROD_OLD, 
                                 @V_IDFGESPEATIV_OLD, 
                                 @V_IDAJUSFGESPE_OLD,

                                 @V_CDPRODUTO_NEW,    
                                 @V_CDESPEPROD_NEW,   
                                 @V_NRFGESPEPROD_NEW, 
                                 @V_IDFGESPEATIV_NEW, 
                                 @V_IDAJUSFGESPE_NEW;

   END;

   CLOSE      C_CURSOR;
   DEALLOCATE C_CURSOR;

END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'LOG_CDP_FOTOESPEPROD','5.07.000';
GO
